# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`sentinelone_agent`](#sentinelone_agent): Manage an installation of the SentinelOne Agent
* [`sentinelone_agent::config`](#sentinelone_agent--config): Manage the SentinelOne Agent configuration
* [`sentinelone_agent::install`](#sentinelone_agent--install): Manage the SentinelOne Agent installation
* [`sentinelone_agent::service`](#sentinelone_agent--service): Manage the SentinelOne Agent service

### Defined types

* [`sentinelone_agent::option`](#sentinelone_agent--option): Control an option in the SentinelOne Agent configuration file

## Classes

### <a name="sentinelone_agent"></a>`sentinelone_agent`

Manage an installation of the SentinelOne Agent

#### Examples

#####

```puppet
class { 'sentinelone_agent':
  token => 'abc123',
}
```

#### Parameters

The following parameters are available in the `sentinelone_agent` class:

* [`logrotate_ensure`](#-sentinelone_agent--logrotate_ensure)
* [`manage_logrotate`](#-sentinelone_agent--manage_logrotate)
* [`manage_package`](#-sentinelone_agent--manage_package)
* [`manage_service`](#-sentinelone_agent--manage_service)
* [`options`](#-sentinelone_agent--options)
* [`package_ensure`](#-sentinelone_agent--package_ensure)
* [`package_name`](#-sentinelone_agent--package_name)
* [`service_enable`](#-sentinelone_agent--service_enable)
* [`service_ensure`](#-sentinelone_agent--service_ensure)
* [`service_name`](#-sentinelone_agent--service_name)
* [`token`](#-sentinelone_agent--token)

##### <a name="-sentinelone_agent--logrotate_ensure"></a>`logrotate_ensure`

Data type: `Enum['absent', 'present']`

Ensure whether the logrotate file is present or not (default: 'present').

##### <a name="-sentinelone_agent--manage_logrotate"></a>`manage_logrotate`

Data type: `Boolean`

Decide whether to manage the logrotate configuration for the service (default: true).

##### <a name="-sentinelone_agent--manage_package"></a>`manage_package`

Data type: `Boolean`

Decide whether to manage the package (default: true).

##### <a name="-sentinelone_agent--manage_service"></a>`manage_service`

Data type: `Boolean`

Decide whether to manage the service (default: true).

##### <a name="-sentinelone_agent--options"></a>`options`

Data type: `Optional[Hash]`

Custom options to be changed in the SentinelOne Agent configuration

##### <a name="-sentinelone_agent--package_ensure"></a>`package_ensure`

Data type: `Variant[Enum['absent', 'installed', 'latest'], Pattern[/^(\d+\.){3}\d+$/]]`

Ensure the state of the package (default: 'installed').

##### <a name="-sentinelone_agent--package_name"></a>`package_name`

Data type: `String`

The name of the SentinelOne agent package (default: 'SentinelAgent').

##### <a name="-sentinelone_agent--service_enable"></a>`service_enable`

Data type: `Boolean`

Decide whether to enable the service (default: true).

##### <a name="-sentinelone_agent--service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Ensure the state of the service (default: 'running').

##### <a name="-sentinelone_agent--service_name"></a>`service_name`

Data type: `String`

The name of the SentinelOne agent service (default: 'sentinelone').

##### <a name="-sentinelone_agent--token"></a>`token`

Data type: `String`

The token to be used by the SentinelOne agent (no default, but required)

### <a name="sentinelone_agent--config"></a>`sentinelone_agent::config`

Manage the SentinelOne Agent configuration

### <a name="sentinelone_agent--install"></a>`sentinelone_agent::install`

Manage the SentinelOne Agent installation

### <a name="sentinelone_agent--service"></a>`sentinelone_agent::service`

Manage the SentinelOne Agent service

## Defined types

### <a name="sentinelone_agent--option"></a>`sentinelone_agent::option`

Control an option in the SentinelOne Agent configuration file

#### Examples

#####

```puppet
sentinelone_agent::option { 'mgmt_proxy_url':
  value => 'http://example.org:8888',
}
```

#####

```puppet
sentinelone_agent::option { 'some_option_name':
  setting => 'mgmt_proxy_url'
  value   => 'http://example.org:8888',
}
```

#### Parameters

The following parameters are available in the `sentinelone_agent::option` defined type:

* [`value`](#-sentinelone_agent--option--value)
* [`setting`](#-sentinelone_agent--option--setting)

##### <a name="-sentinelone_agent--option--value"></a>`value`

Data type: `String`

The value to set for the given option.

##### <a name="-sentinelone_agent--option--setting"></a>`setting`

Data type: `Optional[String]`

Optionally set the option name. If not provided, the resource title will be used.

Default value: `undef`
